@@ -47,7 +47,7 @@ def validate(pkg_name: str = None,
 @click.option('--sermos-yaml', required=False, default=None)
 @click.option('--commit-hash', required=False, default=None)
 @click.option('--deploy-url', required=False, default=None)
-@click.option('--deploy-branch', required=False, default='master')
+@click.option('--deploy-branch', required=False, default='main')
 def deploy(access_key: str = None,
            pkg_name: str = None,
            sermos_yaml: str = None,
@@ -73,7 +73,7 @@ def deploy(access_key: str = None,
             deploy-url (optional): Defaults to primary sermos deployment
                 endpoint. Only modify this if there is a specific, known reason
                 to do so.
-            deploy-branch (optional): Defaults to 'master'.
+            deploy-branch (optional): Defaults to 'main'.
                 Only modify this if there is a specific, known reason to do so.
     """
     # Instantiate SermosDeploy
